# Conversational RAG examples
Here we curate different examples of how to build a Conversational RAG agent using different approaches/backends.

## [Simple Example](simple_example/)
This example demonstrates how to build a conversational RAG agent with "memory".

The "memory" here is stored in state, which Burr then can help you track,
manage, and introspect.


## [Graph DB Example](graph_db_example/)
This demo illustrates how to build a RAG Q&A AI agent over the [UFC stats dataset](https://www.kaggle.com/datasets/rajeevw/ufcdata).
This one uses a Knowledge Graph that is stored in [FalkorDB](https://www.falkordb.com/) to query for
information about UFC fighters and fights.
